@@ -5,6 +5,8 @@ use crate::{
     SqlDataType, SqlReturn, StatementAttribute, ULen, USmallInt, WChar,
 };
 
+pub static mut NUM_ENVIRONMENT: u32 = 0;
+
 // static linking is not currently supported here for windows
 #[cfg_attr(windows, link(name = "odbc32"))]
 #[cfg_attr(
@@ -260,7 +262,7 @@ extern "system" {
         name_length_2: SmallInt,
         table_name: *const Char,
         name_length_3: SmallInt,
-        TableType: *const Char,
+        table_type: *const Char,
         name_length_4: SmallInt,
     ) -> SqlReturn;
 
@@ -509,6 +511,26 @@ extern "system" {
     pub fn SQLCopyDesc(source_desc_handle: HDesc, target_desc_handle: HDesc) -> SqlReturn;
 
     /// Returns the current setting of a connection attribute.
+    /// 
+    /// * `buffer_length`: is either buffer length or one of [`crate::IS_POINTER`],
+    ///   [`crate::IS_UINTEGER`], [`crate::IS_INTEGER`], [`crate::IS_USMALLINT`] or
+    ///   [`crate::IS_SMALLINT`].
+    ///
+    /// # Returns
+    /// `SUCCESS`, `ERROR`, `SQL_NO_DATA`, or `INVALID_HANDLE`.
+    pub fn SQLGetConnectAttr(
+        connection_handle: HDbc,
+        attribute: ConnectionAttribute,
+        value_ptr: Pointer,
+        buffer_length: Integer,
+        string_length_ptr: *mut Integer,
+    ) -> SqlReturn;
+
+    /// Returns the current setting of a connection attribute.
+    /// 
+    /// * `buffer_length`: is either buffer length or one of [`crate::IS_POINTER`],
+    ///   [`crate::IS_UINTEGER`], [`crate::IS_INTEGER`], [`crate::IS_USMALLINT`] or
+    ///   [`crate::IS_SMALLINT`].
     ///
     /// # Returns
     /// `SUCCESS`, `ERROR`, `SQL_NO_DATA`, or `INVALID_HANDLE`.
